# Changelog

## 1.34.0 (2024-11-09)

Full Changelog: [v1.33.0...v1.34.0](https://github.com/julep-ai/python-sdk/compare/v1.33.0...v1.34.0)

### Features

* **api:** api update ([#142](https://github.com/julep-ai/python-sdk/issues/142)) ([d3563f2](https://github.com/julep-ai/python-sdk/commit/d3563f2b712eaeeece097ef66f13b171fd10d044))

## 1.33.0 (2024-11-07)

Full Changelog: [v1.32.0...v1.33.0](https://github.com/julep-ai/python-sdk/compare/v1.32.0...v1.33.0)

### Features

* **api:** add custom api key; change uuid4 to uuid ([#8](https://github.com/julep-ai/python-sdk/issues/8)) ([cd7c76f](https://github.com/julep-ai/python-sdk/commit/cd7c76f817f3e69897bda62e2695a2e5ccfd5a8f))
* **api:** api update ([#100](https://github.com/julep-ai/python-sdk/issues/100)) ([4db7881](https://github.com/julep-ai/python-sdk/commit/4db7881d5add7cbd936d22a828ff1de9a0c57262))
* **api:** api update ([#103](https://github.com/julep-ai/python-sdk/issues/103)) ([01dbb00](https://github.com/julep-ai/python-sdk/commit/01dbb00fe174f518a4df80e4a2c02c7f6bba02d9))
* **api:** api update ([#109](https://github.com/julep-ai/python-sdk/issues/109)) ([ba242c8](https://github.com/julep-ai/python-sdk/commit/ba242c8aedc6c68d0c9dc3485a82afc86626255b))
* **api:** api update ([#112](https://github.com/julep-ai/python-sdk/issues/112)) ([8246545](https://github.com/julep-ai/python-sdk/commit/824654586047a2ad10420ef54545adea5ecfe345))
* **api:** api update ([#116](https://github.com/julep-ai/python-sdk/issues/116)) ([9c81e90](https://github.com/julep-ai/python-sdk/commit/9c81e90e0adf094ea5648311b1fe59f5c1400d76))
* **api:** api update ([#119](https://github.com/julep-ai/python-sdk/issues/119)) ([3bb1c3a](https://github.com/julep-ai/python-sdk/commit/3bb1c3a90b1a0018f621ff0360e13713d838e918))
* **api:** api update ([#122](https://github.com/julep-ai/python-sdk/issues/122)) ([f9096c6](https://github.com/julep-ai/python-sdk/commit/f9096c62b5b86a9673f0298e28a27d5a523eb656))
* **api:** api update ([#135](https://github.com/julep-ai/python-sdk/issues/135)) ([a1794d8](https://github.com/julep-ai/python-sdk/commit/a1794d8a8fc3397c61927b8e3a762fba49c0b9ac))
* **api:** api update ([#75](https://github.com/julep-ai/python-sdk/issues/75)) ([f3ebc89](https://github.com/julep-ai/python-sdk/commit/f3ebc891876b39d7fb564560e1d347c9c8e39810))
* **api:** api update ([#79](https://github.com/julep-ai/python-sdk/issues/79)) ([db5ea21](https://github.com/julep-ai/python-sdk/commit/db5ea21698fc85b67d20eafd64ea96df92ea4f55))
* **api:** api update ([#84](https://github.com/julep-ai/python-sdk/issues/84)) ([4343377](https://github.com/julep-ai/python-sdk/commit/43433776948eb4a3c44fbb6e746ea44489c16aab))
* **api:** api update ([#87](https://github.com/julep-ai/python-sdk/issues/87)) ([170e31a](https://github.com/julep-ai/python-sdk/commit/170e31ae2670755e80578a4b19551e80265bd7d0))
* **api:** api update ([#90](https://github.com/julep-ai/python-sdk/issues/90)) ([b534787](https://github.com/julep-ai/python-sdk/commit/b534787d0b4e32c53a9f0ab5b14b2693f151973e))
* **api:** api update ([#94](https://github.com/julep-ai/python-sdk/issues/94)) ([5e1764d](https://github.com/julep-ai/python-sdk/commit/5e1764db94e0a713b0ef14ac8e0b6d8f0957fb04))
* **api:** api update ([#97](https://github.com/julep-ai/python-sdk/issues/97)) ([38b7218](https://github.com/julep-ai/python-sdk/commit/38b721831e96e125a532fb69911ab9588d751435))
* **api:** manual change nested_format-&gt;dots and array_format->repeat in query settings ([#52](https://github.com/julep-ai/python-sdk/issues/52)) ([22ffd50](https://github.com/julep-ai/python-sdk/commit/22ffd50bd6f027c01c972a5aafd0f7b39e1bd836))
* **api:** OpenAPI spec update via Stainless API ([#19](https://github.com/julep-ai/python-sdk/issues/19)) ([c27c232](https://github.com/julep-ai/python-sdk/commit/c27c232a662f936c8f28ae32d9e19fddca2f6ccd))
* **api:** OpenAPI spec update via Stainless API ([#20](https://github.com/julep-ai/python-sdk/issues/20)) ([d8ff0e5](https://github.com/julep-ai/python-sdk/commit/d8ff0e5d14cee458d3f853491df93da0f0a34fc5))
* **api:** OpenAPI spec update via Stainless API ([#29](https://github.com/julep-ai/python-sdk/issues/29)) ([daf84a2](https://github.com/julep-ai/python-sdk/commit/daf84a2290023007673baceec2b3f7d8f6bb9af6))
* **api:** OpenAPI spec update via Stainless API ([#32](https://github.com/julep-ai/python-sdk/issues/32)) ([e082886](https://github.com/julep-ai/python-sdk/commit/e0828868c9a0e22bc2aab884704857d80627956d))
* **api:** OpenAPI spec update via Stainless API ([#35](https://github.com/julep-ai/python-sdk/issues/35)) ([0601eac](https://github.com/julep-ai/python-sdk/commit/0601eac834ad0a694e203ab3083dfade28bd92cb))
* **api:** OpenAPI spec update via Stainless API ([#41](https://github.com/julep-ai/python-sdk/issues/41)) ([bf50065](https://github.com/julep-ai/python-sdk/commit/bf500659b46812ec2fed862db604bc5e8d9be0ab))
* **api:** OpenAPI spec update via Stainless API ([#43](https://github.com/julep-ai/python-sdk/issues/43)) ([c9f285c](https://github.com/julep-ai/python-sdk/commit/c9f285cde7718ab346c6a035dfaa7b5921fdc178))
* **api:** OpenAPI spec update via Stainless API ([#46](https://github.com/julep-ai/python-sdk/issues/46)) ([a1501ef](https://github.com/julep-ai/python-sdk/commit/a1501ef05661aa9dfc967c54ba89f20a9e2ceecf))
* **api:** OpenAPI spec update via Stainless API ([#49](https://github.com/julep-ai/python-sdk/issues/49)) ([3bb6222](https://github.com/julep-ai/python-sdk/commit/3bb6222a912376625ccd4325c1a17a5a8a30d93b))
* **api:** OpenAPI spec update via Stainless API ([#5](https://github.com/julep-ai/python-sdk/issues/5)) ([9b26042](https://github.com/julep-ai/python-sdk/commit/9b26042873376b09db3f51e66a18118ecca8d69a))
* **api:** OpenAPI spec update via Stainless API ([#57](https://github.com/julep-ai/python-sdk/issues/57)) ([cae5425](https://github.com/julep-ai/python-sdk/commit/cae54258b8a7c46ce9b1478f01d278f0c6f5c019))
* **api:** OpenAPI spec update via Stainless API ([#60](https://github.com/julep-ai/python-sdk/issues/60)) ([5ed1a8d](https://github.com/julep-ai/python-sdk/commit/5ed1a8db473d1de7c95a55742e3aef64d08fe073))
* **api:** OpenAPI spec update via Stainless API ([#63](https://github.com/julep-ai/python-sdk/issues/63)) ([9d97c44](https://github.com/julep-ai/python-sdk/commit/9d97c444de06130719827c93e3b14cd42728e2cd))
* **api:** OpenAPI spec update via Stainless API ([#66](https://github.com/julep-ai/python-sdk/issues/66)) ([26079cb](https://github.com/julep-ai/python-sdk/commit/26079cb9bd7de3b9ba67de5860582410ec03c27b))
* **api:** update via SDK Studio ([99fc2a4](https://github.com/julep-ai/python-sdk/commit/99fc2a47f868f50591c92614a73a57a4604de0ac))
* **api:** update via SDK Studio ([d4c5ba9](https://github.com/julep-ai/python-sdk/commit/d4c5ba9ffd8776d50fd18d187794526459fddad2))
* **api:** update via SDK Studio ([d681e89](https://github.com/julep-ai/python-sdk/commit/d681e89770f3b96bc44549a4d808aaeed8d160bf))
* **api:** update via SDK Studio ([73e713c](https://github.com/julep-ai/python-sdk/commit/73e713c728dd81128b94a15eb258821c30130a50))
* **api:** update via SDK Studio ([4e9f83d](https://github.com/julep-ai/python-sdk/commit/4e9f83d59a40271d00cc546afa5496e779ed90a3))
* **api:** update via SDK Studio ([8f60449](https://github.com/julep-ai/python-sdk/commit/8f60449dc1ffe285142118e185da8517c6468667))
* **api:** update via SDK Studio ([dda74e1](https://github.com/julep-ai/python-sdk/commit/dda74e10af0fff634ceaccfb8c7eb7b0f705226a))
* **api:** update via SDK Studio ([e8c3b6f](https://github.com/julep-ai/python-sdk/commit/e8c3b6fcc486eab93bc48e442303381849128601))
* **api:** update via SDK Studio ([d287c9f](https://github.com/julep-ai/python-sdk/commit/d287c9fab4dca657672d3c4495fb2c6ef37508f3))
* **api:** update via SDK Studio ([e7b85a3](https://github.com/julep-ai/python-sdk/commit/e7b85a3e0a5f1206d65a19544a74378a04987b00))
* **api:** update via SDK Studio ([949a676](https://github.com/julep-ai/python-sdk/commit/949a676bb310f28fff7806d39e8e254cb135b75d))
* **api:** update via SDK Studio ([281bafd](https://github.com/julep-ai/python-sdk/commit/281bafd01d7a9c8a3e2f3a3f57fd0e647f7d5ca5))
* **client:** send retry count header ([#17](https://github.com/julep-ai/python-sdk/issues/17)) ([8f99506](https://github.com/julep-ai/python-sdk/commit/8f995066384e390b1a1a4e514c4493702a2145d0))
* deps: Add dotenv as a bundled dep ([08fd755](https://github.com/julep-ai/python-sdk/commit/08fd7557f1bd334a2be302090bdfb3545e18d540))
* various codegen changes ([779a7e3](https://github.com/julep-ai/python-sdk/commit/779a7e3682819e8e7a83f0ddaf9052d62c280fb6))


### Bug Fixes

* **client:** avoid OverflowError with very large retry counts ([#69](https://github.com/julep-ai/python-sdk/issues/69)) ([67375a3](https://github.com/julep-ai/python-sdk/commit/67375a31c5c773e1fb01152ac5d6120965c1a1ce))
* **client:** handle domains with underscores ([#15](https://github.com/julep-ai/python-sdk/issues/15)) ([eb905a1](https://github.com/julep-ai/python-sdk/commit/eb905a138dfc235308b630268efd14132daa2774))
* Extend create and create_or_update methods for tasks ([be6ac8e](https://github.com/julep-ai/python-sdk/commit/be6ac8e133b7456bc167c158323da0edb74cdd1d))
* Fix import ([405e1db](https://github.com/julep-ai/python-sdk/commit/405e1dba578da2732373431bbae0e4b802554699))
* Fix positional args handling ([fdb1d64](https://github.com/julep-ai/python-sdk/commit/fdb1d642376caab9dd59e00621a5fce2a042dad0))
* **lib:** Fix inspect args logic ([cbe409c](https://github.com/julep-ai/python-sdk/commit/cbe409cb7f33ad0b5cd17e8a59c1f491146007ae))
* Pop extra args from argument list ([b2133aa](https://github.com/julep-ai/python-sdk/commit/b2133aa4f9df8b825c3ad8dda2b78f4ff1e93a1a))
* remove unused import ([a5c7b48](https://github.com/julep-ai/python-sdk/commit/a5c7b48b155ea4231a16ac8f7b74b8eb0b8e2feb))


### Chores

* add repr to PageInfo class ([#72](https://github.com/julep-ai/python-sdk/issues/72)) ([4b1d049](https://github.com/julep-ai/python-sdk/commit/4b1d0497ed765df25e1c401a6b414fd58a32223c))
* Fix formatting ([a0b10ef](https://github.com/julep-ai/python-sdk/commit/a0b10ef5b42e43dd15a4de7a2f5e642efa23cc84))
* go live ([#1](https://github.com/julep-ai/python-sdk/issues/1)) ([f720320](https://github.com/julep-ai/python-sdk/commit/f720320217bf4d1935c6270627510dc6329c1df7))
* Ignore attr defined error ([abd8afe](https://github.com/julep-ai/python-sdk/commit/abd8afe890a22a79ee718363d1ab61ed863ab0cb))
* Ignore typing errors ([3de90b1](https://github.com/julep-ai/python-sdk/commit/3de90b100ad1f99c3824bde44699651f22ff7a33))
* **internal:** add support for parsing bool response content ([#54](https://github.com/julep-ai/python-sdk/issues/54)) ([fb290f2](https://github.com/julep-ai/python-sdk/commit/fb290f2119eb9ff66549d1c360b89d8dcb35d92d))
* **internal:** bump pyright / mypy version ([#14](https://github.com/julep-ai/python-sdk/issues/14)) ([e6e180d](https://github.com/julep-ai/python-sdk/commit/e6e180d070a9606268aa42dacfa9fb220bfa57ec))
* **internal:** codegen changes ([#132](https://github.com/julep-ai/python-sdk/issues/132)) ([788174f](https://github.com/julep-ai/python-sdk/commit/788174f87532023544abdda7d78ce67209212069))
* **internal:** codegen related update ([#12](https://github.com/julep-ai/python-sdk/issues/12)) ([8c12efc](https://github.com/julep-ai/python-sdk/commit/8c12efc5d10b0ce84bc760158025b7a34d6fd1fc))
* **internal:** codegen related update ([#27](https://github.com/julep-ai/python-sdk/issues/27)) ([cb98d42](https://github.com/julep-ai/python-sdk/commit/cb98d423b87043de48ca3e845f107b797a69824b))
* **internal:** codegen related update ([#38](https://github.com/julep-ai/python-sdk/issues/38)) ([03c8e84](https://github.com/julep-ai/python-sdk/commit/03c8e84ed43a97c943642703eedaa230166fb055))
* **internal:** codegen related update ([#40](https://github.com/julep-ai/python-sdk/issues/40)) ([d64f86a](https://github.com/julep-ai/python-sdk/commit/d64f86a1b7a47ed0ec53af42f2bf96b4718fc80d))
* **internal:** update pydantic v1 compat helpers ([#22](https://github.com/julep-ai/python-sdk/issues/22)) ([f90bc17](https://github.com/julep-ai/python-sdk/commit/f90bc1783cee6669055f02fe9621f5b70a2f5d89))
* **internal:** use `typing_extensions.overload` instead of `typing` ([#25](https://github.com/julep-ai/python-sdk/issues/25)) ([3c50f29](https://github.com/julep-ai/python-sdk/commit/3c50f297ee48e3a7bc284551a1cd12905bc7ae29))
* rebuild project due to codegen change ([#137](https://github.com/julep-ai/python-sdk/issues/137)) ([70a972d](https://github.com/julep-ai/python-sdk/commit/70a972df3336dc9ebfbd885ee0b80d1e9d4550a6))
* update SDK settings ([#3](https://github.com/julep-ai/python-sdk/issues/3)) ([a603b61](https://github.com/julep-ai/python-sdk/commit/a603b61b57b910e77c602feaf93f9f18bf722a95))

## 1.32.0 (2024-11-07)

Full Changelog: [v1.31.1...v1.32.0](https://github.com/julep-ai/python-sdk/compare/v1.31.1...v1.32.0)

### Features

* **api:** api update ([#135](https://github.com/julep-ai/python-sdk/issues/135)) ([b254016](https://github.com/julep-ai/python-sdk/commit/b254016b177acfb74c8618d4f687163aac59ec4e))

## 1.31.1 (2024-11-02)

Full Changelog: [v1.31.0...v1.31.1](https://github.com/julep-ai/python-sdk/compare/v1.31.0...v1.31.1)

### Bug Fixes

* remove unused import ([cc74aa2](https://github.com/julep-ai/python-sdk/commit/cc74aa29c6030b6e1e6f3922d1cb7342cdedd8c5))


### Chores

* **internal:** codegen changes ([#132](https://github.com/julep-ai/python-sdk/issues/132)) ([bb9600c](https://github.com/julep-ai/python-sdk/commit/bb9600cc75daebccf207b23e0dd8db8bfb9cfef7))

## 1.31.0 (2024-11-02)

Full Changelog: [v1.30.0...v1.31.0](https://github.com/julep-ai/python-sdk/compare/v1.30.0...v1.31.0)

### Features

* various codegen changes ([cdb714e](https://github.com/julep-ai/python-sdk/commit/cdb714e443fbdb6caf9f8a612adfeae21d7e1b2a))


### Bug Fixes

* **lib:** Fix inspect args logic ([cbe409c](https://github.com/julep-ai/python-sdk/commit/cbe409cb7f33ad0b5cd17e8a59c1f491146007ae))

## 1.30.0 (2024-11-01)

Full Changelog: [v1.29.0...v1.30.0](https://github.com/julep-ai/python-sdk/compare/v1.29.0...v1.30.0)

### Features

* **api:** api update ([#122](https://github.com/julep-ai/python-sdk/issues/122)) ([bd300dc](https://github.com/julep-ai/python-sdk/commit/bd300dcb1c2e03b245a5fd7795b5fd64732555fa))
* Update __init__.py ([ab075ee](https://github.com/julep-ai/python-sdk/commit/ab075ee89466bdd2848ac6431b0d2a7829a00e3e))

## 1.29.0 (2024-11-01)

Full Changelog: [v1.28.0...v1.29.0](https://github.com/julep-ai/python-sdk/compare/v1.28.0...v1.29.0)

### Features

* **api:** api update ([#119](https://github.com/julep-ai/python-sdk/issues/119)) ([05c25ee](https://github.com/julep-ai/python-sdk/commit/05c25ee9df8c4b87f40a40285c2b18662fd82104))

## 1.28.0 (2024-10-31)

Full Changelog: [v1.27.0...v1.28.0](https://github.com/julep-ai/python-sdk/compare/v1.27.0...v1.28.0)

### Features

* **api:** api update ([#116](https://github.com/julep-ai/python-sdk/issues/116)) ([25b96db](https://github.com/julep-ai/python-sdk/commit/25b96db8eafee879d7da26f07cb2666c44a1d02e))

## 1.27.0 (2024-10-31)

Full Changelog: [v1.26.0...v1.27.0](https://github.com/julep-ai/python-sdk/compare/v1.26.0...v1.27.0)

### Features

* **api:** api update ([#112](https://github.com/julep-ai/python-sdk/issues/112)) ([d9c4b22](https://github.com/julep-ai/python-sdk/commit/d9c4b22022ee8fdf43cc080e700635ff4bd0d180))

## 1.26.0 (2024-10-30)

Full Changelog: [v1.25.1...v1.26.0](https://github.com/julep-ai/python-sdk/compare/v1.25.1...v1.26.0)

### Features

* **api:** api update ([#109](https://github.com/julep-ai/python-sdk/issues/109)) ([a6fbe4c](https://github.com/julep-ai/python-sdk/commit/a6fbe4c0cd2c250d2b2fee3454a9aee7cfa78ac8))

## 1.25.1 (2024-10-30)

Full Changelog: [v1.25.0...v1.25.1](https://github.com/julep-ai/python-sdk/compare/v1.25.0...v1.25.1)

### Bug Fixes

* Fix import ([405e1db](https://github.com/julep-ai/python-sdk/commit/405e1dba578da2732373431bbae0e4b802554699))


### Chores

* Fix formatting ([a0b10ef](https://github.com/julep-ai/python-sdk/commit/a0b10ef5b42e43dd15a4de7a2f5e642efa23cc84))
* Ignore attr defined error ([abd8afe](https://github.com/julep-ai/python-sdk/commit/abd8afe890a22a79ee718363d1ab61ed863ab0cb))
* Ignore typing errors ([3de90b1](https://github.com/julep-ai/python-sdk/commit/3de90b100ad1f99c3824bde44699651f22ff7a33))

## 1.25.0 (2024-10-30)

Full Changelog: [v1.24.0...v1.25.0](https://github.com/julep-ai/python-sdk/compare/v1.24.0...v1.25.0)

### Features

* **api:** api update ([#103](https://github.com/julep-ai/python-sdk/issues/103)) ([7bebd2c](https://github.com/julep-ai/python-sdk/commit/7bebd2c9252b476821df1704ae636d8e88c70d77))

## 1.24.0 (2024-10-29)

Full Changelog: [v1.23.0...v1.24.0](https://github.com/julep-ai/python-sdk/compare/v1.23.0...v1.24.0)

### Features

* **api:** api update ([#100](https://github.com/julep-ai/python-sdk/issues/100)) ([0797355](https://github.com/julep-ai/python-sdk/commit/0797355a735592816b671d6fcadcc74f2bc51f6f))

## 1.23.0 (2024-10-29)

Full Changelog: [v1.22.0...v1.23.0](https://github.com/julep-ai/python-sdk/compare/v1.22.0...v1.23.0)

### Features

* **api:** api update ([#97](https://github.com/julep-ai/python-sdk/issues/97)) ([0ce9e8a](https://github.com/julep-ai/python-sdk/commit/0ce9e8a02d536ded730984148c834606c2ba0885))

## 1.22.0 (2024-10-29)

Full Changelog: [v1.21.0...v1.22.0](https://github.com/julep-ai/python-sdk/compare/v1.21.0...v1.22.0)

### Features

* **api:** api update ([#94](https://github.com/julep-ai/python-sdk/issues/94)) ([34965df](https://github.com/julep-ai/python-sdk/commit/34965df8e42611263e5dc7b05ab2d69fad917dd1))

## 1.21.0 (2024-10-26)

Full Changelog: [v1.20.0...v1.21.0](https://github.com/julep-ai/python-sdk/compare/v1.20.0...v1.21.0)

### Features

* **api:** api update ([#90](https://github.com/julep-ai/python-sdk/issues/90)) ([ee0e9f3](https://github.com/julep-ai/python-sdk/commit/ee0e9f3edae1941e4d25d64e5473604624635b77))

## 1.20.0 (2024-10-22)

Full Changelog: [v1.19.0...v1.20.0](https://github.com/julep-ai/python-sdk/compare/v1.19.0...v1.20.0)

### Features

* **api:** api update ([#87](https://github.com/julep-ai/python-sdk/issues/87)) ([d527d77](https://github.com/julep-ai/python-sdk/commit/d527d775ceafdc68a4464e0def71453c161ad00b))

## 1.19.0 (2024-10-19)

Full Changelog: [v1.18.0...v1.19.0](https://github.com/julep-ai/python-sdk/compare/v1.18.0...v1.19.0)

### Features

* **api:** api update ([#84](https://github.com/julep-ai/python-sdk/issues/84)) ([6e33e65](https://github.com/julep-ai/python-sdk/commit/6e33e65fd81c9c4dd3848e505fe02f0cc5775b34))

## 1.18.0 (2024-10-18)

Full Changelog: [v1.17.0...v1.18.0](https://github.com/julep-ai/python-sdk/compare/v1.17.0...v1.18.0)

### Features

* deps: Add dotenv as a bundled dep ([08fd755](https://github.com/julep-ai/python-sdk/commit/08fd7557f1bd334a2be302090bdfb3545e18d540))

## 1.17.0 (2024-10-18)

Full Changelog: [v1.16.0...v1.17.0](https://github.com/julep-ai/python-sdk/compare/v1.16.0...v1.17.0)

### Features

* **api:** api update ([#79](https://github.com/julep-ai/python-sdk/issues/79)) ([50f22a4](https://github.com/julep-ai/python-sdk/commit/50f22a49c7c9d12f7315236803832340aacf1029))

## 1.16.0 (2024-10-10)

Full Changelog: [v1.15.2...v1.16.0](https://github.com/julep-ai/python-sdk/compare/v1.15.2...v1.16.0)

### Features

* **api:** api update ([#75](https://github.com/julep-ai/python-sdk/issues/75)) ([6db4387](https://github.com/julep-ai/python-sdk/commit/6db4387c664a099f45c0ac8d716767060bbc8732))

## 1.15.2 (2024-10-07)

Full Changelog: [v1.15.1...v1.15.2](https://github.com/julep-ai/python-sdk/compare/v1.15.1...v1.15.2)

### Chores

* add repr to PageInfo class ([#72](https://github.com/julep-ai/python-sdk/issues/72)) ([4b1d049](https://github.com/julep-ai/python-sdk/commit/4b1d0497ed765df25e1c401a6b414fd58a32223c))

## 1.15.1 (2024-10-07)

Full Changelog: [v1.15.0...v1.15.1](https://github.com/julep-ai/python-sdk/compare/v1.15.0...v1.15.1)

### Bug Fixes

* **client:** avoid OverflowError with very large retry counts ([#69](https://github.com/julep-ai/python-sdk/issues/69)) ([7e9c5de](https://github.com/julep-ai/python-sdk/commit/7e9c5ded74f129cdb0cbb84c804c8e892c22fe8b))

## 1.15.0 (2024-10-07)

Full Changelog: [v1.14.0...v1.15.0](https://github.com/julep-ai/python-sdk/compare/v1.14.0...v1.15.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#66](https://github.com/julep-ai/python-sdk/issues/66)) ([cfc33cc](https://github.com/julep-ai/python-sdk/commit/cfc33ccd90a18cce8539c8bd3398e90505b45934))

## 1.14.0 (2024-10-05)

Full Changelog: [v1.13.0...v1.14.0](https://github.com/julep-ai/python-sdk/compare/v1.13.0...v1.14.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#63](https://github.com/julep-ai/python-sdk/issues/63)) ([fbd636d](https://github.com/julep-ai/python-sdk/commit/fbd636d3c2962f2e8ad8f927ba604c13df62423a))

## 1.13.0 (2024-10-05)

Full Changelog: [v1.12.0...v1.13.0](https://github.com/julep-ai/python-sdk/compare/v1.12.0...v1.13.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#60](https://github.com/julep-ai/python-sdk/issues/60)) ([1bb231a](https://github.com/julep-ai/python-sdk/commit/1bb231a3dc7e5012c241cf3a83829e8fbbcf4cec))

## 1.12.0 (2024-10-05)

Full Changelog: [v1.11.1...v1.12.0](https://github.com/julep-ai/python-sdk/compare/v1.11.1...v1.12.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#57](https://github.com/julep-ai/python-sdk/issues/57)) ([d2a2f6f](https://github.com/julep-ai/python-sdk/commit/d2a2f6f2cdae0599e06b6772ef7176948bb18dcc))

## 1.11.1 (2024-10-04)

Full Changelog: [v1.11.0...v1.11.1](https://github.com/julep-ai/python-sdk/compare/v1.11.0...v1.11.1)

### Chores

* **internal:** add support for parsing bool response content ([#54](https://github.com/julep-ai/python-sdk/issues/54)) ([fb290f2](https://github.com/julep-ai/python-sdk/commit/fb290f2119eb9ff66549d1c360b89d8dcb35d92d))

## 1.11.0 (2024-10-04)

Full Changelog: [v1.10.0...v1.11.0](https://github.com/julep-ai/python-sdk/compare/v1.10.0...v1.11.0)

### Features

* **api:** manual change nested_format-&gt;dots and array_format->repeat in query settings ([#52](https://github.com/julep-ai/python-sdk/issues/52)) ([51c5ad8](https://github.com/julep-ai/python-sdk/commit/51c5ad8fa7a9a31e3d1d5ace3b7e052c1f22b589))

## 1.10.0 (2024-10-04)

Full Changelog: [v1.9.0...v1.10.0](https://github.com/julep-ai/python-sdk/compare/v1.9.0...v1.10.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#49](https://github.com/julep-ai/python-sdk/issues/49)) ([7e6100c](https://github.com/julep-ai/python-sdk/commit/7e6100c26e9189a6f7d8db0ab003b5aa3cd20412))

## 1.9.0 (2024-10-04)

Full Changelog: [v1.8.0...v1.9.0](https://github.com/julep-ai/python-sdk/compare/v1.8.0...v1.9.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#46](https://github.com/julep-ai/python-sdk/issues/46)) ([9ec3586](https://github.com/julep-ai/python-sdk/commit/9ec358673c6294b10b795a79659b315f12ec3043))

## 1.8.0 (2024-10-03)

Full Changelog: [v1.7.0...v1.8.0](https://github.com/julep-ai/python-sdk/compare/v1.7.0...v1.8.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#43](https://github.com/julep-ai/python-sdk/issues/43)) ([584193e](https://github.com/julep-ai/python-sdk/commit/584193ee4cb0c8162f34a31377605685f74a2ab8))

## 1.7.0 (2024-10-02)

Full Changelog: [v1.6.0...v1.7.0](https://github.com/julep-ai/python-sdk/compare/v1.6.0...v1.7.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#41](https://github.com/julep-ai/python-sdk/issues/41)) ([917f242](https://github.com/julep-ai/python-sdk/commit/917f2426867ce8596f3e95803434c554c7da6cca))


### Chores

* **internal:** codegen related update ([#38](https://github.com/julep-ai/python-sdk/issues/38)) ([09aee2a](https://github.com/julep-ai/python-sdk/commit/09aee2a3e59cbbb932cfe459bda1cb28614d9803))
* **internal:** codegen related update ([#40](https://github.com/julep-ai/python-sdk/issues/40)) ([4d768b7](https://github.com/julep-ai/python-sdk/commit/4d768b75e0361f8a8a0edd690511f8c4410b88f7))

## 1.6.0 (2024-10-01)

Full Changelog: [v1.5.0...v1.6.0](https://github.com/julep-ai/python-sdk/compare/v1.5.0...v1.6.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#35](https://github.com/julep-ai/python-sdk/issues/35)) ([316651d](https://github.com/julep-ai/python-sdk/commit/316651db98a3bc64dd6a236acb0ab6064f65bbaf))

## 1.5.0 (2024-09-25)

Full Changelog: [v1.4.0...v1.5.0](https://github.com/julep-ai/python-sdk/compare/v1.4.0...v1.5.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#32](https://github.com/julep-ai/python-sdk/issues/32)) ([f359535](https://github.com/julep-ai/python-sdk/commit/f3595355079ad286913b6ac8516f98220c6cb8a4))

## 1.4.0 (2024-09-25)

Full Changelog: [v1.3.2...v1.4.0](https://github.com/julep-ai/python-sdk/compare/v1.3.2...v1.4.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#29](https://github.com/julep-ai/python-sdk/issues/29)) ([4223a5c](https://github.com/julep-ai/python-sdk/commit/4223a5c207e93acc0ede043b76d3dbc0e731e7a7))

## 1.3.2 (2024-09-25)

Full Changelog: [v1.3.1...v1.3.2](https://github.com/julep-ai/python-sdk/compare/v1.3.1...v1.3.2)

### Chores

* **internal:** codegen related update ([#27](https://github.com/julep-ai/python-sdk/issues/27)) ([cb98d42](https://github.com/julep-ai/python-sdk/commit/cb98d423b87043de48ca3e845f107b797a69824b))
* **internal:** use `typing_extensions.overload` instead of `typing` ([#25](https://github.com/julep-ai/python-sdk/issues/25)) ([3c50f29](https://github.com/julep-ai/python-sdk/commit/3c50f297ee48e3a7bc284551a1cd12905bc7ae29))

## 1.3.1 (2024-09-24)

Full Changelog: [v1.3.0...v1.3.1](https://github.com/julep-ai/python-sdk/compare/v1.3.0...v1.3.1)

### Chores

* **internal:** update pydantic v1 compat helpers ([#22](https://github.com/julep-ai/python-sdk/issues/22)) ([f90bc17](https://github.com/julep-ai/python-sdk/commit/f90bc1783cee6669055f02fe9621f5b70a2f5d89))

## 1.3.0 (2024-09-23)

Full Changelog: [v1.2.1...v1.3.0](https://github.com/julep-ai/python-sdk/compare/v1.2.1...v1.3.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#19](https://github.com/julep-ai/python-sdk/issues/19)) ([c27c232](https://github.com/julep-ai/python-sdk/commit/c27c232a662f936c8f28ae32d9e19fddca2f6ccd))
* **api:** OpenAPI spec update via Stainless API ([#20](https://github.com/julep-ai/python-sdk/issues/20)) ([d8ff0e5](https://github.com/julep-ai/python-sdk/commit/d8ff0e5d14cee458d3f853491df93da0f0a34fc5))
* **client:** send retry count header ([#17](https://github.com/julep-ai/python-sdk/issues/17)) ([8f99506](https://github.com/julep-ai/python-sdk/commit/8f995066384e390b1a1a4e514c4493702a2145d0))

## 1.2.1 (2024-09-19)

Full Changelog: [v1.2.0...v1.2.1](https://github.com/julep-ai/python-sdk/compare/v1.2.0...v1.2.1)

### Bug Fixes

* **client:** handle domains with underscores ([#15](https://github.com/julep-ai/python-sdk/issues/15)) ([f00026b](https://github.com/julep-ai/python-sdk/commit/f00026bf6cd9360eab7620d145add2616b4d3702))


### Chores

* **internal:** bump pyright / mypy version ([#14](https://github.com/julep-ai/python-sdk/issues/14)) ([73a4b15](https://github.com/julep-ai/python-sdk/commit/73a4b151a593dfa38523586d3511ee5ebfc663f1))
* **internal:** codegen related update ([#12](https://github.com/julep-ai/python-sdk/issues/12)) ([4309b50](https://github.com/julep-ai/python-sdk/commit/4309b50db10f755f0d57a8638b97356058e4d93e))

## 1.2.0 (2024-09-19)

Full Changelog: [v1.1.0...v1.2.0](https://github.com/julep-ai/python-sdk/compare/v1.1.0...v1.2.0)

### Features

* **api:** add custom api key; change uuid4 to uuid ([#8](https://github.com/julep-ai/python-sdk/issues/8)) ([7b2488e](https://github.com/julep-ai/python-sdk/commit/7b2488e990dea41628541cb9311a802d5f7ba884))

## 1.1.0 (2024-09-13)

Full Changelog: [v1.0.1...v1.1.0](https://github.com/julep-ai/python-sdk/compare/v1.0.1...v1.1.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#5](https://github.com/julep-ai/python-sdk/issues/5)) ([9b26042](https://github.com/julep-ai/python-sdk/commit/9b26042873376b09db3f51e66a18118ecca8d69a))

## 1.0.1 (2024-09-13)

Full Changelog: [v0.0.1-alpha.0...v1.0.1](https://github.com/julep-ai/python-sdk/compare/v0.0.1-alpha.0...v1.0.1)

### Features

* **api:** update via SDK Studio ([99fc2a4](https://github.com/julep-ai/python-sdk/commit/99fc2a47f868f50591c92614a73a57a4604de0ac))
* **api:** update via SDK Studio ([d4c5ba9](https://github.com/julep-ai/python-sdk/commit/d4c5ba9ffd8776d50fd18d187794526459fddad2))
* **api:** update via SDK Studio ([d681e89](https://github.com/julep-ai/python-sdk/commit/d681e89770f3b96bc44549a4d808aaeed8d160bf))
* **api:** update via SDK Studio ([73e713c](https://github.com/julep-ai/python-sdk/commit/73e713c728dd81128b94a15eb258821c30130a50))
* **api:** update via SDK Studio ([4e9f83d](https://github.com/julep-ai/python-sdk/commit/4e9f83d59a40271d00cc546afa5496e779ed90a3))
* **api:** update via SDK Studio ([8f60449](https://github.com/julep-ai/python-sdk/commit/8f60449dc1ffe285142118e185da8517c6468667))
* **api:** update via SDK Studio ([dda74e1](https://github.com/julep-ai/python-sdk/commit/dda74e10af0fff634ceaccfb8c7eb7b0f705226a))
* **api:** update via SDK Studio ([e8c3b6f](https://github.com/julep-ai/python-sdk/commit/e8c3b6fcc486eab93bc48e442303381849128601))
* **api:** update via SDK Studio ([d287c9f](https://github.com/julep-ai/python-sdk/commit/d287c9fab4dca657672d3c4495fb2c6ef37508f3))
* **api:** update via SDK Studio ([e7b85a3](https://github.com/julep-ai/python-sdk/commit/e7b85a3e0a5f1206d65a19544a74378a04987b00))
* **api:** update via SDK Studio ([949a676](https://github.com/julep-ai/python-sdk/commit/949a676bb310f28fff7806d39e8e254cb135b75d))
* **api:** update via SDK Studio ([281bafd](https://github.com/julep-ai/python-sdk/commit/281bafd01d7a9c8a3e2f3a3f57fd0e647f7d5ca5))


### Chores

* go live ([#1](https://github.com/julep-ai/python-sdk/issues/1)) ([f720320](https://github.com/julep-ai/python-sdk/commit/f720320217bf4d1935c6270627510dc6329c1df7))
* update SDK settings ([#3](https://github.com/julep-ai/python-sdk/issues/3)) ([a603b61](https://github.com/julep-ai/python-sdk/commit/a603b61b57b910e77c602feaf93f9f18bf722a95))
